#! /usr/bin/perl -w

use strict;
use warnings;

my $line;

my $vmware = 'vmware';

if (not open(CFG, '<', '/etc/vmware/locations')) {
	printf STDERR "Unable to find VMware installation database. Using '%s'.\n", $vmware;
} else {
	my $bindir;

	while (defined($line = <CFG>)) {
		chomp $line;
		if ($line =~ /^answer BINDIR (.*)$/) {
			$bindir = $1;
		}
	}
	close CFG;

	if (not defined($bindir)) {
		printf STDERR "Unable to find path to the VMware in installation database. Using '%s'.\n", $vmware;
	} else {
		$vmware = $bindir.'/vmware';
	}
}

my $type;
my $protocol;
my $build;
my $product;

open VMWARE, "$vmware -v < /dev/null 2>&1 |" or die 'Cannot start VMware using `'.$vmware.'\'!';
while (defined($line = <VMWARE>)) {
	chomp $line;
	
	if ($line =~ /VMware (.*) protocol=(.*) build=(.*) product='(.*)'/) {
		($type, $protocol, $build, $product) = ($1, $2, $3, $4);
	} elsif (not defined($type) and $line =~ /VMware (.*) (\d+(?:\.\d+)*|e\.x\.p) build-(\d+)/) {
		($type, $protocol, $build, $product) = ($1, '6', $3, "$2 $3");
	}
}
close VMWARE;

if (not defined($type)) {
	print STDERR "VMware 2 or VMware Express detected, building for VMware 2, VMware Express and VMware Workstation 4.0.x.\n";
	print 'VME_V4';
	exit 0;
}
if ($type =~ /GSX/i) {
	if ($product =~ /^1\./) {
		print STDERR "Building for VMware GSX Server 1.x.x.\n";
		print 'VME_GSX1';
		exit 0;
	}
	if ($product =~ /^2\.0/) {
		print STDERR "Building for VMware GSX Server 2.0.x.\n";
		print 'VME_GSX2';
		exit 0;
	}
	if ($product =~ /^2\.5\.[1-9]/) {
		print STDERR "Building for VMware GSX Server 2.5.1.\n";
		print 'VME_GSX251';
		exit 0;
	}
	if ($product =~ /^2\.5/) {
		print STDERR "Building for VMware GSX Server 2.5.0.\n";
		print 'VME_GSX25';
		exit 0;
	}
	if ($product =~ /^3\.0/) {
		print STDERR "Building for VMware GSX Server 3.0.0 or VMware Workstation 4.5.1.\n";
		print 'VME_V45';
		exit 0;
	}
	if ($product =~ /^3\.1/) {
		print STDERR "Building for VMware GSX Server 3.1.0 or VMware Workstation 4.5.2.\n";
		print 'VME_V452';
		exit 0;
	}
	print STDERR "Unknown VMware GSX Server $product detected. Building for TOT.\n";
	print 'VME_TOT';
	exit 0;
} elsif ($type =~ /Workstation/i) {
	if ($product =~ /^3\.[01]\./) {
		print STDERR "Building for VMware Workstation 3.0.x.\n";
		print 'VME_V3';
		exit 0;
	}
	if ($product =~ /^3\.2\.0/) {
		print STDERR "Building for VMware Workstation 3.2.0.\n";
		print 'VME_V32';
		exit 0;
	}
	if ($product =~ /^3\.2\./) {
		print STDERR "Building for VMware Workstation 3.2.1.\n";
		print 'VME_V321';
		exit 0;
	}
	if ($product =~ /^4\.0\./) {
		print STDERR "Building for VMware Workstation 4.0.x.\n";
		print 'VME_V4';
		exit 0;
	}
	if ($product =~ /^4\.5\.[01]/) {
		print STDERR "Building for VMware Workstation 4.5.1 or VMware GSX Server 3.0.0.\n";
		print 'VME_V45';
		exit 0;
	}
	if ($product =~ /^4\.5\.[2-9]/) {
		print STDERR "Building for VMware Workstation 4.5.2 or VMware GSX Server 3.1.0.\n";
		print 'VME_V452';
		exit 0;
	}
	if ($product =~ /^e\.x\.p/) {
		if ($build eq '11608' or $build eq '11888') {
			print STDERR "Building for VMware Workstation 5.0.0 beta 2 build 11608 or 11888.\n";
			print 'VME_V5B2';
			exit 0;
		}
	}
	print STDERR "Unknown VMware Workstation $product detected. Building for TOT.\n";
	print 'VME_TOT';
	exit 0;
}
print STDERR "Unknown product ($type) detected. Building for TOT.\n";
print 'VME_TOT';
exit 0;
